@@ -194,14 +194,26 @@ as.data.frame.par_struct <- function(object, ...){
 }
 
 
-add_parstyle_column <- function(x, type = "html"){
+add_parstyle_column <- function(x, type = "html", text.direction, valign){
 
   if( type %in% "html"){
     shading <- ifelse( colalpha(x$shading.color) > 0,
                        sprintf("background-color:%s;", colcodecss(x$shading.color) ),
                        "background-color:transparent;")
 
+    textdir <- ifelse(text.direction %in% "tbrl", "writing-mode:vertical-rl;",
+                      ifelse(text.direction %in% "btlr", "writing-mode:vertical-lr;transform: rotate(180deg);", "")
+                      )
     textalign <- sprintf("text-align:%s;", x$text.align )
+    textalign_margins <- rep("", length(text.direction))
+
+    textalign_margins[text.direction %in% "tbrl" & valign %in% "center"] <- "margin-left:auto;margin-right:auto;"
+    textalign_margins[text.direction %in% "tbrl" & valign %in% "top"] <- "margin-left:auto;"
+    textalign_margins[text.direction %in% "tbrl" & valign %in% "bottom"] <- "margin-right:auto;"
+    textalign_margins[text.direction %in% "btlr" & valign %in% "center"] <- "margin-left:auto;margin-right:auto;"
+    textalign_margins[text.direction %in% "btlr" & valign %in% "top"] <- "margin-right:auto;"
+    textalign_margins[text.direction %in% "btlr" & valign %in% "bottom"] <- "margin-left:auto;"
+    textalign <- paste0(textalign, textalign_margins)
 
     bb <- border_css(
       color = x$border.color.bottom, width = x$border.width.bottom,
@@ -221,7 +233,7 @@ add_parstyle_column <- function(x, type = "html"){
     padding.left <- sprintf("padding-left:%s;", css_px(x$padding.left) )
     padding.right <- sprintf("padding-right:%s;", css_px(x$padding.right) )
 
-    style_column <- paste0("style=\"margin:0;", textalign, bb, bt, bl, br,
+    style_column <- paste0("style=\"margin:0;", textalign, textdir, bb, bt, bl, br,
                            padding.bottom, padding.top, padding.left, padding.right, shading, "\"" )
   } else if( type %in% "wml"){
 
@@ -268,9 +280,9 @@ add_parstyle_column <- function(x, type = "html"){
   x[, c("row_id", "col_id", "style_str")]
 }
 
-par_data <- function(x, run_data, type){
+par_data <- function(x, run_data, type, text.direction, valign){
   paragraphs <- as.data.frame(x)
-  paragraphs <- add_parstyle_column(paragraphs, type = type)
+  paragraphs <- add_parstyle_column(paragraphs, type = type, text.direction = text.direction, valign = valign)
   setDT(paragraphs)
   dat <- merge(paragraphs, run_data, by = c("row_id", "col_id"), all.x = TRUE)
   setDF(paragraphs)
@@ -297,7 +309,7 @@ cell_struct <- function( nrow, keys,
                          border.width.bottom = 1, border.width.top = 1, border.width.left = 1, border.width.right = 1,
                          border.color.bottom = "transparent", border.color.top = "transparent", border.color.left = "transparent", border.color.right = "transparent",
                          border.style.bottom = "solid", border.style.top = "solid", border.style.left = "solid", border.style.right = "solid",
-                         background.color = "#34CC27", width = NA_real_, height = NA_real_ ){
+                         background.color = "#34CC27", width = NA_real_, height = NA_real_, hrule = "auto" ){
 
   check_choice( value = vertical.align, choices = c( "top", "center", "bottom" ) )
   check_choice( value = text.direction, choices = c( "lrtb", "tbrl", "btlr" ) )
@@ -329,7 +341,8 @@ cell_struct <- function( nrow, keys,
 
 
     text.direction = fpstruct(nrow = nrow, keys = keys, default = text.direction),
-    background.color = fpstruct(nrow = nrow, keys = keys, default = background.color)
+    background.color = fpstruct(nrow = nrow, keys = keys, default = background.color),
+    hrule = fpstruct(nrow = nrow, keys = keys, default = hrule)
   )
   class(x) <- "cell_struct"
   x
@@ -375,7 +388,7 @@ as.data.frame.cell_struct <- function(object, ...){
   data
 }
 
-add_cellstyle_column <- function(x, type = "html"){
+add_cellstyle_column <- function(x, type = "html", text.align ){
 
   if( type %in% "html"){
     background.color <- ifelse( colalpha(x$background.color) > 0,
@@ -383,10 +396,14 @@ add_cellstyle_column <- function(x, type = "html"){
                        "background-color:transparent;")
 
     width <- ifelse( is.na(x$width), "", sprintf("width:%s;", css_px(x$width * 72) ) )
-    height <- ifelse( is.na(x$height), "", sprintf("height:%s;", css_px(x$height * 72 ) ) )
+    height <- ifelse( is.na(x$height) | x$hrule %in% "exact", sprintf("height:%s;", css_px(x$height * 72 ) ), "" )
+
     vertical.align <- ifelse(
       x$vertical.align %in% "center", "vertical-align: middle;",
       ifelse(x$vertical.align %in% "top", "vertical-align: top;", "vertical-align: bottom;") )
+    vertical.align[x$text.direction %in% "tbrl" & text.align %in% "center"] <- "vertical-align:middle;"
+    vertical.align[x$text.direction %in% "tbrl" & text.align %in% "left"] <- "vertical-align:top;"
+    vertical.align[x$text.direction %in% "tbrl" & text.align %in% "right"] <- "vertical-align:bottom;"
 
     bb <- border_css(
       color = x$border.color.bottom, width = x$border.width.bottom,
@@ -478,11 +495,12 @@ add_cellstyle_column <- function(x, type = "html"){
   x[, c("row_id", "col_id", "style_str")]
 }
 
-cell_data <- function(x, par_data, type, span_rows, span_columns, colwidths, rowheights){
+cell_data <- function(x, par_data, type, span_rows, span_columns, colwidths, rowheights, hrule, text.align){
   x[,, "width"] <- rep(colwidths, each = x$vertical.align$nrow)
   x[,, "height"] <- rep(rowheights, x$vertical.align$ncol)
+  x[,, "hrule"] <- rep(hrule, x$vertical.align$ncol)
   cells <- as.data.frame(x)
-  cells <- add_cellstyle_column(cells, type = type)
+  cells <- add_cellstyle_column(cells, type = type, text.align = text.align)
   setDT(cells)
   dat <- merge(cells, par_data, by = c("row_id", "col_id"), all.x = TRUE)
 
@@ -528,8 +546,8 @@ cell_data <- function(x, par_data, type, span_rows, span_columns, colwidths, row
 
     text_directions <- x$text.direction[]
     class_ <- character(nrow(dat))
-    rotated <- text_directions %in% c("btlr", "tbrl")
-    class_[rotated] <- sprintf(" class=\"%s\"", text_directions[rotated])
+    # rotated <- text_directions %in% c("btlr", "tbrl")
+    # class_[rotated] <- sprintf(" class=\"%s\"", text_directions[rotated])
 
     str <- paste0("<td", class_, tc_attr, " style=\"", dat$style_str ,"\">", dat$par_str, "</td>")
     str[span_rows < 1 | span_columns < 1] <- ""
@@ -711,9 +729,6 @@ add_runstyle_column <- function(x, type = "html"){
       x$vertical.align %in% "superscript", " baseline=\"40000\"",
       ifelse(x$vertical.align %in% "subscript"," baseline=\"-40000\"", "") )
 
-
-    shading <- sprintf("<w:shd w:val=\"clear\" w:color=\"auto\" w:fill=\"%s\"/>", colcode0(x$shading.color) )
-
     color <- paste0(
       sprintf("<a:solidFill><a:srgbClr val=\"%s\">", colcode0(x$color) ),
       sprintf("<a:alpha val=\"%.0f\"/>", colalpha(x$color) ),
@@ -722,6 +737,7 @@ add_runstyle_column <- function(x, type = "html"){
       sprintf("<a:highlight><a:srgbClr val=\"%s\">", colcode0(x$shading.color) ),
       sprintf("<a:alpha val=\"%.0f\"/>", colalpha(x$shading.color) ),
       "</a:srgbClr></a:highlight>" )
+    shading.color[colalpha(x$shading.color) < 1] <- ""
 
     style_column <- paste0("<a:rPr", font.size, italic, bold, underline, vertical.align, ">",
                            color, family, shading.color, "%s",
