@@ -1,12 +1,17 @@
 # utils -----
-css_px <- function(x){
+css_px <- function(x, format = "%.0fpx"){
   ifelse( is.na(x), "inherit",
-          ifelse( x < 0.001, "0", sprintf("%.0fpx", x)) )
+          ifelse( x < 0.001, "0", sprintf(format, x)) )
+}
+
+css_pt <- function(x){
+  ifelse( is.na(x), "inherit",
+          ifelse( x < 0.001, "0", sprintf("%.0fpt", x)) )
 }
 
 border_css <- function(color, width, style, side){
   style[!style %in% c("dotted", "dashed", "solid")] <- "solid"
-  sprintf("border-%s: %s %s %s;", side, css_px(width), style, colcodecss(color))
+  sprintf("border-%s: %s %s %s;", side, css_px(width, "%.2fpx"), style, colcodecss(color))
 }
 border_wml <- function(color, width, style, side){
   width[style %in% c("none")] <- 0
@@ -14,7 +19,7 @@ border_wml <- function(color, width, style, side){
   style[style %in% c("solid")] <- "single"
 
   out <- sprintf('<w:%s w:val="%s" w:sz="%.0f" w:space="0" w:color="%s" />', side, style, width * 8, colcode0(color))
-  out[width < 0.001 | color %in% "transparent"] <- ""
+  out[width < 0.001 | color %in% "transparent"] <- sprintf("<w:%s w:val=\"nil\"/>", side)
   out
 }
 border_pml <- function(color, width, style, side){
@@ -86,22 +91,23 @@ format.complex_tabpart <- function( x, type = "wml", header = FALSE,
 
   }
 
-  paragraphs <- par_data(x$styles$pars, txt_data, type = type)
+  paragraphs <- par_data(x$styles$pars, txt_data, type = type,
+                         text.direction = x$styles$cells$text.direction$data, valign = x$styles$cells$vertical.align$data)
   cells <- cell_data(x$styles$cells, paragraphs, type = type,
                      span_rows = x$spans$rows,
-                     span_columns = x$spans$columns, x$colwidths, x$rowheights)
+                     span_columns = x$spans$columns, x$colwidths, x$rowheights, x$hrule, text.align=x$styles$pars$text.align$data)
   setDT(cells)
   cells <- dcast(cells, row_id ~ col_id, drop=FALSE, fill="", value.var = "cell_str", fun.aggregate = I)
   cells$row_id <- NULL
   cells <- apply(as.matrix(cells), 1, paste0, collapse = "")
 
   if( type == "html"){
-    rows <- paste0("<tr>", cells, "</tr>")
+    rows <- paste0(sprintf("<tr%s>", ifelse(x$hrule %in% "exact", "", " style=\"overflow-wrap:break-word;\"")), cells, "</tr>")
   } else if( type == "wml"){
     rows <- paste0( "<w:tr><w:trPr>",
             ifelse(split, "", "<w:cantSplit/>"),
             "<w:trHeight w:val=",
-            shQuote( round(x$rowheights * 72*20, 0 ), type = "cmd"), " w:hRule=\"exact\"/>",
+            shQuote( round(x$rowheights * 72*20, 0 ), type = "cmd"), " w:hRule=\"", ifelse(x$hrule %in% "atleast", "atLeast", x$hrule) ,"\"/>",
             ifelse( header, "<w:tblHeader/>", ""),
             "</w:trPr>", cells, "</w:tr>")
   } else if( type == "pml"){
